@@ -1,23 +1,12 @@
 /*
-  Copyright (c) 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-    Author: Allen Winter <allen.winter@kdab.com>
-  Copyright (C) 2014 Sergio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Allen Winter <allen.winter@kdab.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+  SPDX-FileCopyrightText: 2014 Sergio Martins <iamsergio@gmail.com>
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 /**
   @file
   This file is part of the API for handling calendar data and provides
@@ -67,7 +56,7 @@ public:
     }
 
     QMap<KJob *, ReceivedInfo> mJobToReceivedInfo;
-    QPointer<QWidget> mParent;
+    QPointer<QWidget> const mParent;
 };
 
 AttachmentHandler::AttachmentHandler(QWidget *parent) : QObject(parent)
@@ -211,7 +200,7 @@ void AttachmentHandler::view(const QString &attachmentName, const QString &uid)
 {
     Item item;
     item.setGid(uid);
-    ItemFetchJob *job = new ItemFetchJob(item);
+    auto *job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
     ReceivedInfo info;
     info.attachmentName = attachmentName;
@@ -269,7 +258,7 @@ void AttachmentHandler::saveAs(const QString &attachmentName, const QString &uid
 {
     Item item;
     item.setGid(uid);
-    ItemFetchJob *job = new ItemFetchJob(item);
+    auto *job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
 
     ReceivedInfo info;
@@ -289,7 +278,7 @@ void AttachmentHandler::slotFinishSaveAs(KJob *job)
     bool success = false;
 
     if (job->error() != 0) {
-        ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
@@ -311,7 +300,7 @@ void AttachmentHandler::slotFinishView(KJob *job)
     bool success = false;
 
     if (job->error()) {
-        ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
