@@ -1,26 +1,10 @@
 /*
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (C) 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2008 Ron Goodheart <rong.dev@gmail.com>
-  Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
+  SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "calprintpluginbase.h"
@@ -38,7 +22,6 @@
 #include <QAbstractTextDocumentLayout>
 #include <QFrame>
 #include <QLabel>
-#include <QPainter>
 #include <QTextCursor>
 #include <QTextDocument>
 #include <QTextDocumentFragment>
@@ -112,7 +95,7 @@ public:
         happens on the given day */
     bool overlaps(CellItem *o) const override
     {
-        PrintCellItem *other = static_cast<PrintCellItem *>(o);
+        auto *other = static_cast<PrintCellItem *>(o);
         return !(other->start() >= end() || other->end() <= start());
     }
 
@@ -144,7 +127,7 @@ CalPrintPluginBase::~CalPrintPluginBase()
 QWidget *CalPrintPluginBase::createConfigWidget(QWidget *w)
 {
     QFrame *wdg = new QFrame(w);
-    QVBoxLayout *layout = new QVBoxLayout(wdg);
+    auto *layout = new QVBoxLayout(wdg);
 
     QLabel *title = new QLabel(description(), wdg);
     QFont titleFont(title->font());
@@ -248,9 +231,9 @@ void CalPrintPluginBase::setPrintFooter(bool printFooter)
     mPrintFooter = printFooter;
 }
 
-QPrinter::Orientation CalPrintPluginBase::orientation() const
+QPageLayout::Orientation CalPrintPluginBase::orientation() const
 {
-    return mPrinter ? mPrinter->orientation() : QPrinter::Portrait;
+    return mPrinter ? mPrinter->pageLayout().orientation() : QPageLayout::Portrait;
 }
 
 QColor CalPrintPluginBase::getTextColor(const QColor &c) const
@@ -342,7 +325,7 @@ int CalPrintPluginBase::headerHeight() const
 {
     if (mHeaderHeight >= 0) {
         return mHeaderHeight;
-    } else if (orientation() == QPrinter::Portrait) {
+    } else if (orientation() == QPageLayout::Portrait) {
         return PORTRAIT_HEADER_HEIGHT;
     } else {
         return LANDSCAPE_HEADER_HEIGHT;
@@ -372,7 +355,7 @@ int CalPrintPluginBase::footerHeight() const
 
     if (mFooterHeight >= 0) {
         return mFooterHeight;
-    } else if (orientation() == QPrinter::Portrait) {
+    } else if (orientation() == QPageLayout::Portrait) {
         return PORTRAIT_FOOTER_HEIGHT;
     } else {
         return LANDSCAPE_FOOTER_HEIGHT;
@@ -961,7 +944,7 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p, const KCalendarCore::Even
 
     QListIterator<CellItem *> it2(cells);
     while (it2.hasNext()) {
-        PrintCellItem *placeItem = static_cast<PrintCellItem *>(it2.next());
+        auto *placeItem = static_cast<PrintCellItem *>(it2.next());
         drawAgendaItem(placeItem, p, startPrintDate, endPrintDate, minlen, box,
                        includeDescription, excludeTime);
     }
@@ -1673,7 +1656,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p, const QDate &dt, const QRect &bo
     QFont oldfont(p.font());
     p.setFont(QFont(QStringLiteral("sans-serif"), 7));
     while (it1.hasNext()) {
-        PrintCellItem *placeItem = static_cast<PrintCellItem *>(it1.next());
+        auto *placeItem = static_cast<PrintCellItem *>(it1.next());
         int minsToStart = starttime.secsTo(placeItem->start()) / 60;
         int minsToEnd = starttime.secsTo(placeItem->end()) / 60;
 
